Class: Google::Cloud::ContainerAnalysis::V1::ContainerAnalysisClient

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/container_analysis/v1/container_analysis_client.rb

Overview

Retrieves analysis results of Cloud components such as Docker container images. The Container Analysis API is an implementation of the Grafeas API.

Analysis results are stored as a series of occurrences. An Occurrence contains information about a specific analysis instance on a resource. An occurrence refers to a Note. A note contains details describing the analysis and is generally stored in a separate project, called a Provider. Multiple occurrences can refer to the same note.

For example, an SSL vulnerability could affect multiple images. In this case, there would be one note for the vulnerability and an occurrence for each image with the vulnerability referring to that note.

Constant Summary collapse

SERVICE_ADDRESS =

The default address of the service.

"containeranalysis.googleapis.com".freeze
DEFAULT_SERVICE_PORT =

The default port of the service.

443
GRPC_INTERCEPTORS =

The default set of gRPC interceptors.

[]
DEFAULT_TIMEOUT =
30
ALL_SCOPES =

The scopes needed to make gRPC calls to all of the methods defined in this service.

[
  "https://www.googleapis.com/auth/cloud-platform"
].freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(credentials: nil, scopes: ALL_SCOPES, client_config: {}, timeout: DEFAULT_TIMEOUT, metadata: nil, service_address: nil, service_port: nil, exception_transformer: nil, lib_name: nil, lib_version: "") ⇒ ContainerAnalysisClient

Returns a new instance of ContainerAnalysisClient.

Parameters:

  • credentials (Google::Auth::Credentials, String, Hash, GRPC::Core::Channel, GRPC::Core::ChannelCredentials, Proc) (defaults to: nil) —

    Provides the means for authenticating requests made by the client. This parameter can be many types. A Google::Auth::Credentials uses a the properties of its represented keyfile for authenticating requests made by this client. A String will be treated as the path to the keyfile to be used for the construction of credentials for this client. A Hash will be treated as the contents of a keyfile to be used for the construction of credentials for this client. A GRPC::Core::Channel will be used to make calls through. A GRPC::Core::ChannelCredentials for the setting up the RPC client. The channel credentials should already be composed with a GRPC::Core::CallCredentials object. A Proc will be used as an updater_proc for the Grpc channel. The proc transforms the metadata for requests, generally, to give OAuth credentials.

  • scopes (Array<String>) (defaults to: ALL_SCOPES) —

    The OAuth scopes for this service. This parameter is ignored if an updater_proc is supplied.

  • client_config (Hash) (defaults to: {}) —

    A Hash for call options for each method. See Google::Gax#construct_settings for the structure of this data. Falls back to the default config if not specified or the specified config is missing data points.

  • timeout (Numeric) (defaults to: DEFAULT_TIMEOUT) —

    The default timeout, in seconds, for calls made through this client.

  • metadata (Hash) (defaults to: nil) —

    Default metadata to be sent with each request. This can be overridden on a per call basis.

  • service_address (String) (defaults to: nil) —

    Override for the service hostname, or nil to leave as the default.

  • service_port (Integer) (defaults to: nil) —

    Override for the service port, or nil to leave as the default.

  • exception_transformer (Proc) (defaults to: nil) —

    An optional proc that intercepts any exceptions raised during an API call to inject custom error handling.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 144

def initialize \
    credentials: nil,
    scopes: ALL_SCOPES,
    client_config: {},
    timeout: DEFAULT_TIMEOUT,
    metadata: nil,
    service_address: nil,
    service_port: nil,
    exception_transformer: nil,
    lib_name: nil,
    lib_version: ""
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "google/gax/grpc"
  require "google/devtools/containeranalysis/v1/containeranalysis_services_pb"

  credentials ||= Google::Cloud::ContainerAnalysis::V1::Credentials.default

  @grafeas_client = ::Grafeas.new(
    credentials: credentials, scopes: scopes, client_config: client_config,
    timeout: timeout, lib_name: lib_name, lib_version: lib_version,
    service_address: service_address, service_port: service_port, metadata: )

  if credentials.is_a?(String) || credentials.is_a?(Hash)
    updater_proc = Google::Cloud::ContainerAnalysis::V1::Credentials.new(credentials).updater_proc
  end
  if credentials.is_a?(GRPC::Core::Channel)
    channel = credentials
  end
  if credentials.is_a?(GRPC::Core::ChannelCredentials)
    chan_creds = credentials
  end
  if credentials.is_a?(Proc)
    updater_proc = credentials
  end
  if credentials.is_a?(Google::Auth::Credentials)
    updater_proc = credentials.updater_proc
  end

  package_version = Google::Cloud::ContainerAnalysis::VERSION

  google_api_client = "gl-ruby/#{RUBY_VERSION}"
  google_api_client << " #{lib_name}/#{lib_version}" if lib_name
  google_api_client << " gapic/#{package_version} gax/#{Google::Gax::VERSION}"
  google_api_client << " grpc/#{GRPC::VERSION}"
  google_api_client.freeze

  headers = { :"x-goog-api-client" => google_api_client }
  headers.merge!() unless .nil?
  client_config_file = Pathname.new(__dir__).join(
    "container_analysis_client_config.json"
  )
  defaults = client_config_file.open do |f|
    Google::Gax.construct_settings(
      "google.devtools.containeranalysis.v1.ContainerAnalysis",
      JSON.parse(f.read),
      client_config,
      Google::Gax::Grpc::STATUS_CODE_NAMES,
      timeout,
      errors: Google::Gax::Grpc::API_ERRORS,
      metadata: headers
    )
  end

  # Allow overriding the service path/port in subclasses.
  service_path = service_address || self.class::SERVICE_ADDRESS
  port = service_port || self.class::DEFAULT_SERVICE_PORT
  interceptors = self.class::GRPC_INTERCEPTORS
  @container_analysis_stub = Google::Gax::Grpc.create_stub(
    service_path,
    port,
    chan_creds: chan_creds,
    channel: channel,
    updater_proc: updater_proc,
    scopes: scopes,
    interceptors: interceptors,
    &Google::Cloud::ContainerAnalysis::V1::ContainerAnalysisService::Stub.method(:new)
  )

  @set_iam_policy = Google::Gax.create_api_call(
    @container_analysis_stub.method(:set_iam_policy),
    defaults["set_iam_policy"],
    exception_transformer: exception_transformer,
    params_extractor: proc do |request|
      {'resource' => request.resource}
    end
  )
  @get_iam_policy = Google::Gax.create_api_call(
    @container_analysis_stub.method(:get_iam_policy),
    defaults["get_iam_policy"],
    exception_transformer: exception_transformer,
    params_extractor: proc do |request|
      {'resource' => request.resource}
    end
  )
  @test_iam_permissions = Google::Gax.create_api_call(
    @container_analysis_stub.method(:test_iam_permissions),
    defaults["test_iam_permissions"],
    exception_transformer: exception_transformer,
    params_extractor: proc do |request|
      {'resource' => request.resource}
    end
  )
end

Instance Attribute Details

#grafeas_client ⇒ Grafeas::V1::GrafeasClient (readonly)

Returns a client for the Grafeas service.

Returns:

  • (Grafeas::V1::GrafeasClient) —

    a client for the Grafeas service



57
58
59
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 57

def grafeas_client
  @grafeas_client
end

Class Method Details

.note_path(project, note) ⇒ String

Returns a fully-qualified note resource name string.

Parameters:

  • project (String)
  • note (String)

Returns:

  • (String)


93
94
95
96
97
98
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 93

def self.note_path project, note
  NOTE_PATH_TEMPLATE.render(
    :"project" => project,
    :"note" => note
  )
end

.occurrence_path(project, occurrence) ⇒ String

Returns a fully-qualified occurrence resource name string.

Parameters:

  • project (String)
  • occurrence (String)

Returns:

  • (String)


104
105
106
107
108
109
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 104

def self.occurrence_path project, occurrence
  OCCURRENCE_PATH_TEMPLATE.render(
    :"project" => project,
    :"occurrence" => occurrence
  )
end

Instance Method Details

#get_iam_policy(resource, options_: nil, options: nil) {|result, operation| ... } ⇒ Google::Iam::V1::Policy

Gets the access control policy for a note or an occurrence resource. Requires containeranalysis.notes.setIamPolicy or containeranalysis.occurrences.setIamPolicy permission if the resource is a note or occurrence, respectively.

The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for occurrences.

Examples:

require "google/cloud/container_analysis"

container_analysis_client = Google::Cloud::ContainerAnalysis.new(version: :v1)
formatted_resource = Google::Cloud::ContainerAnalysis::V1::ContainerAnalysisClient.note_path("[PROJECT]", "[NOTE]")
response = container_analysis_client.get_iam_policy(formatted_resource)

Parameters:

  • resource (String) —

    REQUIRED: The resource for which the policy is being requested. See the operation documentation for the appropriate value for this field.

  • options_ (Google::Iam::V1::GetPolicyOptions | Hash) (defaults to: nil) —

    OPTIONAL: A GetPolicyOptions object for specifying options to GetIamPolicy. This field is only used by Cloud IAM. A hash of the same form as Google::Iam::V1::GetPolicyOptions can also be provided.

  • options (Google::Gax::CallOptions) (defaults to: nil) —

    Overrides the default settings for this call, e.g, timeout, retries, etc.

Yields:

  • (result, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Gax::GaxError) —

    if the RPC is aborted.



334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 334

def get_iam_policy \
    resource,
    options_: nil,
    options: nil,
    &block
  req = {
    resource: resource,
    options: options_
  }.delete_if { |_, v| v.nil? }
  req = Google::Gax::to_proto(req, Google::Iam::V1::GetIamPolicyRequest)
  @get_iam_policy.call(req, options, &block)
end

#set_iam_policy(resource, policy, options: nil) {|result, operation| ... } ⇒ Google::Iam::V1::Policy

Sets the access control policy on the specified note or occurrence. Requires containeranalysis.notes.setIamPolicy or containeranalysis.occurrences.setIamPolicy permission if the resource is a note or an occurrence, respectively.

The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for occurrences.

Examples:

require "google/cloud/container_analysis"

container_analysis_client = Google::Cloud::ContainerAnalysis.new(version: :v1)
formatted_resource = Google::Cloud::ContainerAnalysis::V1::ContainerAnalysisClient.note_path("[PROJECT]", "[NOTE]")

# TODO: Initialize `policy`:
policy = {}
response = container_analysis_client.set_iam_policy(formatted_resource, policy)

Parameters:

  • resource (String) —

    REQUIRED: The resource for which the policy is being specified. See the operation documentation for the appropriate value for this field.

  • policy (Google::Iam::V1::Policy | Hash) —

    REQUIRED: The complete policy to be applied to the resource. The size of the policy is limited to a few 10s of KB. An empty policy is a valid policy but certain Cloud Platform services (such as Projects) might reject them. A hash of the same form as Google::Iam::V1::Policy can also be provided.

  • options (Google::Gax::CallOptions) (defaults to: nil) —

    Overrides the default settings for this call, e.g, timeout, retries, etc.

Yields:

  • (result, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Gax::GaxError) —

    if the RPC is aborted.



289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 289

def set_iam_policy \
    resource,
    policy,
    options: nil,
    &block
  req = {
    resource: resource,
    policy: policy
  }.delete_if { |_, v| v.nil? }
  req = Google::Gax::to_proto(req, Google::Iam::V1::SetIamPolicyRequest)
  @set_iam_policy.call(req, options, &block)
end

#test_iam_permissions(resource, permissions, options: nil) {|result, operation| ... } ⇒ Google::Iam::V1::TestIamPermissionsResponse

Returns the permissions that a caller has on the specified note or occurrence. Requires list permission on the project (for example, containeranalysis.notes.list).

The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for occurrences.

Examples:

require "google/cloud/container_analysis"

container_analysis_client = Google::Cloud::ContainerAnalysis.new(version: :v1)
formatted_resource = Google::Cloud::ContainerAnalysis::V1::ContainerAnalysisClient.note_path("[PROJECT]", "[NOTE]")

# TODO: Initialize `permissions`:
permissions = []
response = container_analysis_client.test_iam_permissions(formatted_resource, permissions)

Parameters:

  • resource (String) —

    REQUIRED: The resource for which the policy detail is being requested. See the operation documentation for the appropriate value for this field.

  • permissions (Array<String>) —

    The set of permissions to check for the resource. Permissions with wildcards (such as '' or 'storage.') are not allowed. For more information see IAM Overview.

  • options (Google::Gax::CallOptions) (defaults to: nil) —

    Overrides the default settings for this call, e.g, timeout, retries, etc.

Yields:

  • (result, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (Google::Gax::GaxError) —

    if the RPC is aborted.



381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 381

def test_iam_permissions \
    resource,
    permissions,
    options: nil,
    &block
  req = {
    resource: resource,
    permissions: permissions
  }.delete_if { |_, v| v.nil? }
  req = Google::Gax::to_proto(req, Google::Iam::V1::TestIamPermissionsRequest)
  @test_iam_permissions.call(req, options, &block)
end