Class: Google::Iam::V1::GetPolicyOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/google/cloud/container_analysis/v1/doc/google/iam/v1/options.rb

Overview

Encapsulates settings provided to GetIamPolicy.

Instance Attribute Summary collapse

Instance Attribute Details

#requested_policy_version ⇒ Integer

Optional. The policy format version to be returned. Acceptable values are 0 and 1. If the value is 0, or the field is omitted, policy format version 1 will be returned.

Returns:

  • (Integer) —

    Optional. The policy format version to be returned. Acceptable values are 0 and 1. If the value is 0, or the field is omitted, policy format version 1 will be returned.



26
# File 'lib/google/cloud/container_analysis/v1/doc/google/iam/v1/options.rb', line 26

class GetPolicyOptions; end