Class: Google::Cloud::ContainerAnalysis::V1::ContainerAnalysisClient
- Inherits:
-
Object
- Object
- Google::Cloud::ContainerAnalysis::V1::ContainerAnalysisClient
- Defined in:
- lib/google/cloud/container_analysis/v1/container_analysis_client.rb
Overview
Retrieves analysis results of Cloud components such as Docker container images. The Container Analysis API is an implementation of the Grafeas API.
Analysis results are stored as a series of occurrences. An Occurrence
contains information about a specific analysis instance on a resource. An
occurrence refers to a Note. A note contains details describing the
analysis and is generally stored in a separate project, called a Provider.
Multiple occurrences can refer to the same note.
For example, an SSL vulnerability could affect multiple images. In this case, there would be one note for the vulnerability and an occurrence for each image with the vulnerability referring to that note.
Constant Summary collapse
- SERVICE_ADDRESS =
The default address of the service.
"containeranalysis.googleapis.com".freeze
- DEFAULT_SERVICE_PORT =
The default port of the service.
443- GRPC_INTERCEPTORS =
The default set of gRPC interceptors.
[]
- DEFAULT_TIMEOUT =
30- ALL_SCOPES =
The scopes needed to make gRPC calls to all of the methods defined in this service.
[ "https://www.googleapis.com/auth/cloud-platform" ].freeze
Instance Attribute Summary collapse
-
#grafeas_client ⇒ Grafeas::V1::GrafeasClient
readonly
A client for the Grafeas service.
Class Method Summary collapse
-
.note_path(project, note) ⇒ String
Returns a fully-qualified note resource name string.
-
.occurrence_path(project, occurrence) ⇒ String
Returns a fully-qualified occurrence resource name string.
Instance Method Summary collapse
-
#get_iam_policy(resource, options_: nil, options: nil) {|result, operation| ... } ⇒ Google::Iam::V1::Policy
Gets the access control policy for a note or an occurrence resource.
-
#initialize(credentials: nil, scopes: ALL_SCOPES, client_config: {}, timeout: DEFAULT_TIMEOUT, metadata: nil, service_address: nil, service_port: nil, exception_transformer: nil, lib_name: nil, lib_version: "") ⇒ ContainerAnalysisClient
constructor
A new instance of ContainerAnalysisClient.
-
#set_iam_policy(resource, policy, options: nil) {|result, operation| ... } ⇒ Google::Iam::V1::Policy
Sets the access control policy on the specified note or occurrence.
-
#test_iam_permissions(resource, permissions, options: nil) {|result, operation| ... } ⇒ Google::Iam::V1::TestIamPermissionsResponse
Returns the permissions that a caller has on the specified note or occurrence.
Constructor Details
#initialize(credentials: nil, scopes: ALL_SCOPES, client_config: {}, timeout: DEFAULT_TIMEOUT, metadata: nil, service_address: nil, service_port: nil, exception_transformer: nil, lib_name: nil, lib_version: "") ⇒ ContainerAnalysisClient
Returns a new instance of ContainerAnalysisClient.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 144 def initialize \ credentials: nil, scopes: ALL_SCOPES, client_config: {}, timeout: DEFAULT_TIMEOUT, metadata: nil, service_address: nil, service_port: nil, exception_transformer: nil, lib_name: nil, lib_version: "" # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "google/gax/grpc" require "google/devtools/containeranalysis/v1/containeranalysis_services_pb" credentials ||= Google::Cloud::ContainerAnalysis::V1::Credentials.default @grafeas_client = ::Grafeas.new( credentials: credentials, scopes: scopes, client_config: client_config, timeout: timeout, lib_name: lib_name, lib_version: lib_version, service_address: service_address, service_port: service_port, metadata: ) if credentials.is_a?(String) || credentials.is_a?(Hash) updater_proc = Google::Cloud::ContainerAnalysis::V1::Credentials.new(credentials).updater_proc end if credentials.is_a?(GRPC::Core::Channel) channel = credentials end if credentials.is_a?(GRPC::Core::ChannelCredentials) chan_creds = credentials end if credentials.is_a?(Proc) updater_proc = credentials end if credentials.is_a?(Google::Auth::Credentials) updater_proc = credentials.updater_proc end package_version = Google::Cloud::ContainerAnalysis::VERSION google_api_client = "gl-ruby/#{RUBY_VERSION}" google_api_client << " #{lib_name}/#{lib_version}" if lib_name google_api_client << " gapic/#{package_version} gax/#{Google::Gax::VERSION}" google_api_client << " grpc/#{GRPC::VERSION}" google_api_client.freeze headers = { :"x-goog-api-client" => google_api_client } headers.merge!() unless .nil? client_config_file = Pathname.new(__dir__).join( "container_analysis_client_config.json" ) defaults = client_config_file.open do |f| Google::Gax.construct_settings( "google.devtools.containeranalysis.v1.ContainerAnalysis", JSON.parse(f.read), client_config, Google::Gax::Grpc::STATUS_CODE_NAMES, timeout, errors: Google::Gax::Grpc::API_ERRORS, metadata: headers ) end # Allow overriding the service path/port in subclasses. service_path = service_address || self.class::SERVICE_ADDRESS port = service_port || self.class::DEFAULT_SERVICE_PORT interceptors = self.class::GRPC_INTERCEPTORS @container_analysis_stub = Google::Gax::Grpc.create_stub( service_path, port, chan_creds: chan_creds, channel: channel, updater_proc: updater_proc, scopes: scopes, interceptors: interceptors, &Google::Cloud::ContainerAnalysis::V1::ContainerAnalysisService::Stub.method(:new) ) @set_iam_policy = Google::Gax.create_api_call( @container_analysis_stub.method(:set_iam_policy), defaults["set_iam_policy"], exception_transformer: exception_transformer, params_extractor: proc do |request| {'resource' => request.resource} end ) @get_iam_policy = Google::Gax.create_api_call( @container_analysis_stub.method(:get_iam_policy), defaults["get_iam_policy"], exception_transformer: exception_transformer, params_extractor: proc do |request| {'resource' => request.resource} end ) @test_iam_permissions = Google::Gax.create_api_call( @container_analysis_stub.method(:test_iam_permissions), defaults["test_iam_permissions"], exception_transformer: exception_transformer, params_extractor: proc do |request| {'resource' => request.resource} end ) end |
Instance Attribute Details
#grafeas_client ⇒ Grafeas::V1::GrafeasClient (readonly)
Returns a client for the Grafeas service.
57 58 59 |
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 57 def grafeas_client @grafeas_client end |
Class Method Details
.note_path(project, note) ⇒ String
Returns a fully-qualified note resource name string.
93 94 95 96 97 98 |
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 93 def self.note_path project, note NOTE_PATH_TEMPLATE.render( :"project" => project, :"note" => note ) end |
.occurrence_path(project, occurrence) ⇒ String
Returns a fully-qualified occurrence resource name string.
104 105 106 107 108 109 |
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 104 def self.occurrence_path project, occurrence OCCURRENCE_PATH_TEMPLATE.render( :"project" => project, :"occurrence" => occurrence ) end |
Instance Method Details
#get_iam_policy(resource, options_: nil, options: nil) {|result, operation| ... } ⇒ Google::Iam::V1::Policy
Gets the access control policy for a note or an occurrence resource.
Requires containeranalysis.notes.setIamPolicy or
containeranalysis.occurrences.setIamPolicy permission if the resource is
a note or occurrence, respectively.
The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for
notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for
occurrences.
334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 334 def get_iam_policy \ resource, options_: nil, options: nil, &block req = { resource: resource, options: }.delete_if { |_, v| v.nil? } req = Google::Gax::to_proto(req, Google::Iam::V1::GetIamPolicyRequest) @get_iam_policy.call(req, , &block) end |
#set_iam_policy(resource, policy, options: nil) {|result, operation| ... } ⇒ Google::Iam::V1::Policy
Sets the access control policy on the specified note or occurrence.
Requires containeranalysis.notes.setIamPolicy or
containeranalysis.occurrences.setIamPolicy permission if the resource is
a note or an occurrence, respectively.
The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for
notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for
occurrences.
289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 289 def set_iam_policy \ resource, policy, options: nil, &block req = { resource: resource, policy: policy }.delete_if { |_, v| v.nil? } req = Google::Gax::to_proto(req, Google::Iam::V1::SetIamPolicyRequest) @set_iam_policy.call(req, , &block) end |
#test_iam_permissions(resource, permissions, options: nil) {|result, operation| ... } ⇒ Google::Iam::V1::TestIamPermissionsResponse
Returns the permissions that a caller has on the specified note or
occurrence. Requires list permission on the project (for example,
containeranalysis.notes.list).
The resource takes the format projects/[PROJECT_ID]/notes/[NOTE_ID] for
notes and projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID] for
occurrences.
381 382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/google/cloud/container_analysis/v1/container_analysis_client.rb', line 381 def \ resource, , options: nil, &block req = { resource: resource, permissions: }.delete_if { |_, v| v.nil? } req = Google::Gax::to_proto(req, Google::Iam::V1::TestIamPermissionsRequest) @test_iam_permissions.call(req, , &block) end |